==> haskell-monad-dijkstra-0.1.1.5-48-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-IUnAyeqcy9opuRsUyx11
key:                  monad-dijkstra-0.1.1.5-IUnAyeqcy9opuRsUyx11
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  454d9af394db4eac19958e6bc51a2d53
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-IUnAyeqcy9opuRsUyx11
depends:
    base-4.16.4.0 containers-0.6.5.1 free-5.1.10-JdZwDRCoHyGAIQAex9ij2v
    mtl-2.2.2 psqueues-0.2.8.0-GPIa45uYdzqL9nP2axtGMr
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-dijkstra-0.1.1.5-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-BH48PoqCFvBE06NdhLJ6xH
key:                  monad-dijkstra-0.1.1.5-BH48PoqCFvBE06NdhLJ6xH
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  bf026128a7ae92b6622ff6adc9e1d0b2
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-BH48PoqCFvBE06NdhLJ6xH
depends:
    base-4.16.4.0 containers-0.6.5.1 free-5.1.10-G0zRLoFgcfkyw2MjpBSHA
    mtl-2.2.2 psqueues-0.2.8.0-4vuoxhvFxLHAeC5Y9E3IEh
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
